==> jc-1.4.0.tar.gz: soot/coffi/Instruction__5fAastore.h <==
// class soot.coffi.Instruction_Aastore

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class dffed07f2d2a766f soot_coffi_Instruction__5fAastore
// @dep_class 741c2648db62361c soot_coffi_Instruction__5fnoargs

// header file dependencies
// @dep_header soot_coffi_Instruction__5fnoargs

#include "soot/coffi/Instruction__5fnoargs.h"

#ifndef _JC_soot_coffi_Instruction__5fAastore_H_
#define _JC_soot_coffi_Instruction__5fAastore_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fAastore$sub_refs	_jc_soot_coffi_Instruction__5fAastore$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fAastore$sub_nonrefs	_jc_soot_coffi_Instruction__5fAastore$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fAastore$refs	_jc_soot_coffi_Instruction__5fAastore$refs;
typedef struct _jc_soot_coffi_Instruction__5fAastore$nonrefs	_jc_soot_coffi_Instruction__5fAastore$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fAastore$object	_jc_soot_coffi_Instruction__5fAastore$object;

typedef const struct _jc_soot_coffi_Instruction__5fAastore$vmethods	_jc_soot_coffi_Instruction__5fAastore$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fAastore$vtable	_jc_soot_coffi_Instruction__5fAastore$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fAastore$vtype	_jc_soot_coffi_Instruction__5fAastore$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fAastore$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fAastore$object *);

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fAastore$vmethods {
};

// Vtable
struct _jc_soot_coffi_Instruction__5fAastore$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fnoargs$vmethods	soot_coffi_Instruction__5fnoargs;
	_jc_soot_coffi_Instruction__5fAastore$vmethods	soot_coffi_Instruction__5fAastore;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fAastore$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fAastore$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fAastore$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fAastore$refs {
    _jc_soot_coffi_Instruction__5fAastore$sub_refs	soot_coffi_Instruction__5fAastore;
    _jc_soot_coffi_Instruction__5fnoargs$sub_refs	soot_coffi_Instruction__5fnoargs;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fAastore$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fAastore$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fnoargs$sub_nonrefs	soot_coffi_Instruction__5fnoargs;
    _jc_soot_coffi_Instruction__5fAastore$sub_nonrefs	soot_coffi_Instruction__5fAastore;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fAastore$object {
	_jc_soot_coffi_Instruction__5fAastore$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fAastore$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fAastore$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fAastore$vtype _jc_soot_coffi_Instruction__5fAastore$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fAastore, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fAastore$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fAastore_H_ */

==> jc-1.4.6.tar.gz: soot/coffi/Instruction__5fAastore.h <==
// class soot.coffi.Instruction_Aastore

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class dffed07f2d2a766f soot_coffi_Instruction__5fAastore
// @dep_class 741c2648db62361c soot_coffi_Instruction__5fnoargs

// header file dependencies
// @dep_header soot_coffi_Instruction__5fnoargs

#include "soot/coffi/Instruction__5fnoargs.h"

#ifndef _JC_soot_coffi_Instruction__5fAastore_H_
#define _JC_soot_coffi_Instruction__5fAastore_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fAastore$sub_refs	_jc_soot_coffi_Instruction__5fAastore$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fAastore$sub_nonrefs	_jc_soot_coffi_Instruction__5fAastore$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fAastore$refs	_jc_soot_coffi_Instruction__5fAastore$refs;
typedef struct _jc_soot_coffi_Instruction__5fAastore$nonrefs	_jc_soot_coffi_Instruction__5fAastore$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fAastore$object	_jc_soot_coffi_Instruction__5fAastore$object;

typedef const struct _jc_soot_coffi_Instruction__5fAastore$vmethods	_jc_soot_coffi_Instruction__5fAastore$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fAastore$vtable	_jc_soot_coffi_Instruction__5fAastore$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fAastore$vtype	_jc_soot_coffi_Instruction__5fAastore$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fAastore$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fAastore$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fAastore$vmethods {
};

// Vtable
struct _jc_soot_coffi_Instruction__5fAastore$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fnoargs$vmethods	soot_coffi_Instruction__5fnoargs;
	_jc_soot_coffi_Instruction__5fAastore$vmethods	soot_coffi_Instruction__5fAastore;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fAastore$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fAastore$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fAastore$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fAastore$refs {
    _jc_soot_coffi_Instruction__5fAastore$sub_refs	soot_coffi_Instruction__5fAastore;
    _jc_soot_coffi_Instruction__5fnoargs$sub_refs	soot_coffi_Instruction__5fnoargs;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fAastore$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fAastore$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fnoargs$sub_nonrefs	soot_coffi_Instruction__5fnoargs;
    _jc_soot_coffi_Instruction__5fAastore$sub_nonrefs	soot_coffi_Instruction__5fAastore;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fAastore$object {
	_jc_soot_coffi_Instruction__5fAastore$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fAastore$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fAastore$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fAastore$vtype _jc_soot_coffi_Instruction__5fAastore$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fAastore, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fAastore$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fAastore_H_ */
